@@ -22,8 +22,9 @@ class Configuration(object):
         except Exception, e:
             raise EntityCfgParseError, e
 
-    def generate_default(self, filehandle=None, conf='basic', store_base_url="http://localhost/",
-                                email='admin@foo.com', name='EntityStore', **general):
+    def generate_default(self, filehandle=None, conf='basic', 
+                         store_base_url="http://localhost:8080/",
+                         email='admin@foo.com', name='EntityStore', **general):
         def add_section(default_cfg, prefix, _name, **kw):
             settings = {}
             settings.update(kw)
@@ -56,6 +57,7 @@ class Configuration(object):
                     base_url=store_base_url,
                     name=name,
                     email=email,
+                    models="conf/models.cfg",
                     **general)
 
         # Add supervisor section:
@@ -74,15 +76,17 @@ class Configuration(object):
 
         # Add multicore solr and 4store services to supervisor list
         # Non-MQ run services start 'service_' by convention
-        add_service(default_cfg, "Solr service", "services/bin/solr.sh")
-        add_service(default_cfg, "4Store backend", "services/bin/4store.sh")
+        add_service(default_cfg, "Solr service", "services/solr.sh")
+        add_service(default_cfg, "EntityStore web api", "./runme.py")
+        add_service(default_cfg, "Redis service", "services/redis/redis-server services/redis/redis.conf")
+        add_service(default_cfg, "4Store backend", "services/4store.sh")
 
         # Workers start with 'worker_' by convention
         # One 4store loader for all stores
         add_worker(default_cfg, 'http4store',
                    'workers/fourstore_loader.py',
                    binding="4store",
-                   host='localhost:5000',
+                   host='http://localhost:5000',
                    amqp="amqp",)
 
         stores = ['people']
@@ -105,16 +109,11 @@ class Configuration(object):
                         objects="genericcontroller",
                         browse="%scontroller" % store)
 
-            add_worker(default_cfg, 'accesslogger_%s' % store, 'workers/logger.py', binding='%s.r' % store,
-                       logfile='logs/%saccess.log' % store)
-
-            add_worker(default_cfg, 'changelogger_%s' % store, 'workers/logger.py', binding='%s.w' % store,
-                       logfile='logs/%schange.log' % store)
-
             add_worker(default_cfg,
                        'solr_%s' % store,
-                       'workers/%s_loader.py' % store,
+                       'workers/solr_loader.py',
                        binding='solr_%s' % store,
+                       model = store,
                        amqp="amqp",
                        title="%s Apache Solr search service" % store,
                        description="""Connection to the /search/ endpoint of this Solr index.
@@ -127,9 +126,11 @@ class Configuration(object):
                        'workers/changemanager.py',
                        binding='%s.w' % store,
                        amqp="amqp",
-                       fanout="solr_%s,4store",
+                       fanout="solr_%s,4store" % store,
                        receipt_q = 'changemanager_%s' % store,
-                       job_store = 'changemanager_%s' % store)
+                       job_store = 'changemanager_%s' % store,
+                       changelog='logs/%schange.log' % store,
+                       accesslog='logs/%saccess.log' % store)
 
         if not filehandle:
             from StringIO import StringIO
