@@ -104,21 +104,23 @@ class Supervisor_Control(object):
                         del worker['worker']
 
                         w_config = ConfigParser()
-                        w_config.add_section(block)
+                        # Workers get there config in the [worker] section
+                        # regardless of name
+                        default_name = "worker"
+                        w_config.add_section(default_name)
                         for (k,v) in worker.items():
                             if k == "amqp" and v in self.c.sections():
                                 # Copy across amqp settings for each worker
                                 w_config.add_section('amqp')
                                 for (a,b) in self.c.items(v):
                                     w_config.set('amqp', a, b)
-                            else:
-                                w_config.set(block, k, v)
-                        fd = open('%s.auto.conf' % block, 'wb')
+                            w_config.set(default_name, k, v)
+                        fd = open('conf/%s.auto.conf' % block, 'wb')
                         w_config.write(fd)
                         fd.close()
                         s_cfg.set('program:%s' % block,
                                   'command',
-                                  " ".join([commandline, '%s.auto.conf' % block]))
+                                  " ".join([commandline, 'conf/%s.auto.conf' % block]))
                     else:
                         s_cfg.set('program:%s' % block,
                                   'command',
@@ -174,15 +176,15 @@ if __name__ == '__main__':
             filename = argv.pop(0)
             if len(argv) >= 1:
                 conf = argv.pop(0)
+
+        if not os.path.isfile(filename):
+            print "Need to supply path for entitystore.cfg"
         else:
-            if not os.path.isfile(filename):
-                print "Need to supply path for entitystore.cfg"
-            else:
-                cfg = ConfigParser()
-                cfg_file = open(filename, 'rb')
-                cfg.readfp(cfg_file)
-                cfg_file.close()
+            cfg = ConfigParser()
+            cfg_file = open(filename, 'rb')
+            cfg.readfp(cfg_file)
+            cfg_file.close()
 
-                s = Supervisor_Control(cfg)
-                s._write_supervisor_config(conf)
+            s = Supervisor_Control(cfg)
+            s._write_supervisor_config(conf)
 
